Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(595)

Unified Diff: build/android/pylib/utils/test_environment.py

Issue 1281923003: [Android] Add --blacklist-file as a command-line option. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: fix telemetry_unittests Created 5 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « build/android/pylib/utils/emulator.py ('k') | build/android/screenshot.py » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: build/android/pylib/utils/test_environment.py
diff --git a/build/android/pylib/utils/test_environment.py b/build/android/pylib/utils/test_environment.py
index f55a4acc100997aeb1bc5b4e7ee69caca73056d8..3b31d4675b4c78619490398d5034cfb3b57ad0db 100644
--- a/build/android/pylib/utils/test_environment.py
+++ b/build/android/pylib/utils/test_environment.py
@@ -30,8 +30,12 @@ def _KillWebServers():
logging.warning('Failed waiting for %s to die. %s', p.pid, e)
-def CleanupLeftoverProcesses():
- """Clean up the test environment, restarting fresh adb and HTTP daemons."""
+def CleanupLeftoverProcesses(devices):
+ """Clean up the test environment, restarting fresh adb and HTTP daemons.
+
+ Args:
+ devices: The devices to clean.
+ """
_KillWebServers()
device_utils.RestartServer()
@@ -43,5 +47,5 @@ def CleanupLeftoverProcesses():
logging.error(str(e))
d.WaitUntilFullyBooted()
- device_utils.DeviceUtils.parallel().pMap(cleanup_device)
+ device_utils.DeviceUtils.parallel(devices).pMap(cleanup_device)
« no previous file with comments | « build/android/pylib/utils/emulator.py ('k') | build/android/screenshot.py » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698